@@ -24,7 +24,7 @@ __all__ = [
 
 class Getsms(object):
 
-    def __init__(self, name='261391761246'):
+    def __init__(self, name='default'):
         self.msisdn = str(name)
         smpp_config = 'SMPP_{}'.format(str(name))
         self.host = CONFIG[smpp_config]['host']
@@ -38,13 +38,13 @@ class Getsms(object):
         name = '{}'.format(str(msisdn))
         return [Getsms(name)]
 
-    def verify_token(self, token):
+    def verify_token(self, auth):
         api_url = '{}/auth/verify-token'.format(
             self.api_url
             )
         result = requests.post(
             api_url,
-            auth=(token, '')
+            auth=auth
             )
         return result
 
